@@ -611,7 +611,8 @@ class PointDwcaReader:
         # Read metadata
         # Get occurrence file ready
         self.file = io.TextIOWrapper(
-            self._zip_archive.open(self.occurrence_filename), encoding='utf8'
+            self._zip_archive.open(self.occurrence_filename),
+            encoding=self.occurrence_params['encoding']
         )
 
         delimiter = self.occurrence_params['fieldsTerminatedBy']
